//
//  MasterViewController.swift
//  schedule
//
//  Created by Илья Лошкарёв on 21.03.2018.
//  Copyright © 2018 SFEDU. All rights reserved.
//

import UIKit

class MasterViewController: UITableViewController {

    weak var schedule: Schedule?

    override func viewDidLoad() {
        super.viewDidLoad()
        schedule = (UIApplication.shared.delegate as! AppDelegate).schedule
    }

    override func viewWillAppear(_ animated: Bool) {
        clearsSelectionOnViewWillAppear = splitViewController!.isCollapsed
        super.viewWillAppear(animated)
    }

    // MARK: - Segues

    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        if segue.identifier == "showDetail"
        {
            if  let indexPath = tableView.indexPathForSelectedRow,
                let object = schedule?.curriculaItems(forLesson: indexPath.row, onDay: indexPath.section),
                let navController = segue.destination as? UINavigationController,
                let controller = navController.topViewController as? DetailViewController
            {
                controller.detailItem = object
                
                controller.navigationItem.leftBarButtonItem = splitViewController?.displayModeButtonItem
                controller.navigationItem.leftItemsSupplementBackButton = true
            }
        }
    }

    // MARK: - TableViewDataSource

    override func numberOfSections(in tableView: UITableView) -> Int {
        // Разбивка по дням
        return schedule?.numberOfWorkDays ?? 0
    }
    
    override func tableView(_ tableView: UITableView, titleForHeaderInSection section: Int) -> String? {
        // Названия дней
        return Calendar.current.weekdaySymbols[(section + Calendar.current.firstWeekday) % 7]
    }

    override func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        // Количество уроков в заданный день
        return schedule?.numberOfLessons(onDay: section) ?? 0
    }
    
    override func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        // Высота строки зависит от количества предметов в паре
        let count = schedule?.numberOfItems(forLesson: indexPath.row, onDay: indexPath.section) ?? 0
        return CGFloat(count) * 60
    }

    override func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: LessonCell.reuseId, for: indexPath) as! LessonCell
        
        cell.setup(for: schedule?.timeslot(forLesson: indexPath.row, onDay: indexPath.section),
                   with: schedule?.curriculaItems(forLesson: indexPath.row, onDay: indexPath.section))
        return cell
    }
}
