//
//  Lesson.swift
//  schedulr
//
//  Created by Илья Лошкарёв on 21.03.2018.
//  Copyright © 2018 SFEDU. All rights reserved.
//

import Foundation

/// Описание аккадемической пары
struct Lesson: Decodable, CustomStringConvertible {
    
    /// Уникальный идентификатор пары
    let id: Int
    /// Количество одновременных предметов
    let curriculaCount: Int
    /// Временной промежуток пары
    let timeslot: String
    
    
    /// Перечесление для преобразования имен полей объекта при сериализации
    enum CodingKeys: String, CodingKey {
        case id;
        case curriculaCount = "subcount";
        case timeslot
    }

    /// Инициализация с помощью декодера JSON
//    public init(from decoder: Decoder) throws {
//        let container = try decoder.container(keyedBy: CodingKeys.self)
//
//        id = try container.decode(Int.self, forKey: .id)
//        curriculaCount = try container.decode(Int.self, forKey: .curriculaCount)
//        timeslot = try container.decode(String.self, forKey: .timeslot)
//    }
    
    var description: String {
        return "\(id):\(timeslot)"
    }
}

/// Тип недели: верхняя/нижняя
enum AlternatingWeek: String, Codable {
    case full, upper, lower
    
    init?(id: Int) {
        switch id {
        case 0: self = .upper
        case 1: self = .lower
        default: return nil
        }
    }
}

/// Премежуток времени
struct Timeslot: CustomStringConvertible {
    
    /// День недели
    let weekday: Int
    /// Время начала
    let startTime: DateComponents
    /// Время окончания
    let endTime: DateComponents
    /// Тип недели
    let alternating: AlternatingWeek
    
    static var inputTimeFormatter : DateFormatter = {
        let df = DateFormatter()
        df.dateFormat = "HH:mm:ss"
        df.timeZone = TimeZone.current
        return df
    }()
    
    init?(_ string: String) {
        guard
            let matches = string.matches(forPattern: "[(]{1}(.+),(.+),(.+),(.+)[)]{1}"),
            let weekday = Int(matches[0][1]),
            let startDate = Timeslot.inputTimeFormatter.date(from: matches[0][2]),
            let endDate = Timeslot.inputTimeFormatter.date(from: matches[0][3]),
            let alternating = AlternatingWeek(rawValue: matches[0][4])
            else { return nil }
        
        var startTime = Calendar.current.dateComponents([.hour,.minute,.second], from: startDate)
        startTime.calendar = Calendar.current
        var endTime = Calendar.current.dateComponents([.hour,.minute,.second], from: endDate)
        endTime.calendar = Calendar.current
        
        self.weekday = weekday
        self.alternating = alternating
        self.startTime = startTime
        self.endTime = endTime
    }
    
    var description: String {
        let timeslotStr = "(\(weekday),\(Timeslot.inputTimeFormatter.string(from: startTime.date!)),\(Timeslot.inputTimeFormatter.string(from: endTime.date!)),\(self.alternating))"
        return timeslotStr
    }
}
